@@ -37,7 +37,7 @@
  *
  * The build type of the installed build.
  */
-#define IDE_BUILD_TYPE "release"
+#define IDE_BUILD_TYPE "debugoptimized"
 
 /**
  * IDE_BUILD_CHANNEL:
@@ -59,21 +59,21 @@
  *
  * libide minor version component (e.g. 2 if %IDE_VERSION is 1.2.3)
  */
-#define IDE_MINOR_VERSION (28)
+#define IDE_MINOR_VERSION (30)
 
 /**
  * IDE_MICRO_VERSION:
  *
  * libide micro version component (e.g. 3 if %IDE_VERSION is 1.2.3)
  */
-#define IDE_MICRO_VERSION (2)
+#define IDE_MICRO_VERSION (1)
 
 /**
  * IDE_VERSION
  *
  * libide version.
  */
-#define IDE_VERSION (3.28.2)
+#define IDE_VERSION (3.30.1)
 
 /**
  * IDE_VERSION_S:
@@ -81,7 +81,7 @@
  * libide version, encoded as a string, useful for printing and
  * concatenation.
  */
-#define IDE_VERSION_S "3.28.2"
+#define IDE_VERSION_S "3.30.1"
 
 #define IDE_ENCODE_VERSION(major,minor,micro) \
         ((major) << 24 | (minor) << 16 | (micro) << 8)
